@@ -1,41 +1,32 @@
 
 package SysAdmin::SMTP;
-use strict;
+use Moose;
 
-use SysAdmin;
+our $VERSION = 0.05;
+
+extends 'SysAdmin';
 use MIME::Lite;
 use Net::SMTP;
-use Carp;
 
-use vars qw(@ISA $VERSION);
+has 'server' => (isa => 'Str', is => 'rw', required => 1, default => "localhost");
 
-our @ISA = qw(SysAdmin);    # inherits from SysAdmin
-our $VERSION = 0.02;
-
-sub new {
-	my $class = shift;
-	my $self = {
-		_smtpServer => shift
-	};
-	
-	bless $self, $class;
-	
-	Carp::croak "No smtp server supplied" unless $self->{_smtpServer};
-	
-	return $self;
-}
+__PACKAGE__->meta->make_immutable;
 
 sub sendEmail {
 	my $self = shift;
 	
-	my $smtp_server = $self->{_smtpServer};
+	my $smtp_server = $self->server();
 	
 	my %attr = @_;
 	
-	my $from_address = $attr{'FROM'};
-    my @email_recipients = @{$attr{'TO'}};
-	my $subject = $attr{'SUBJECT'};
-	my $message_body = $attr{'BODY'};
+	if (ref($attr{'to'}) ne 'ARRAY') {
+		Carp::croak SysAdmin::SMTP::_error("to");
+	}
+	
+	my $from_address = $attr{'from'};
+	my @email_recipients = @{$attr{'to'}};
+	my $subject = $attr{'subject'};
+	my $message_body = $attr{'body'};
 	
 	my $email_recipients = join ",", @email_recipients;
 
@@ -45,12 +36,12 @@ sub sendEmail {
 	From => $from_address,
 	To => $email_recipients,
 	Subject => $subject,
-	Type =>'multipart/alternative') or &dienice ("Error creating multipart container: $!\n");
+	Type =>'multipart/alternative') or die "Error creating multipart container: $!\n";
                                                                    
 	$msg->attach (
 	Type => 'text/html;charset=ISO-8859-1',
 	Encoding => 'quoted-printable',
-	Data => $message_body) or &dienice ("Error adding the text message part: $!\n");
+	Data => $message_body) or die "Error adding the text message part: $!\n";
 
 	my $smtp = Net::SMTP->new($smtp_server, Debug   => 0);
 	die "Couldn\'t connect to server" unless $smtp;
@@ -64,6 +55,44 @@ sub sendEmail {
 	$smtp->quit;
 }
 
+sub _error {
+
+	my ($error) = @_;
+	
+	my $error_to_return = undef;
+	
+	if($error eq "to"){
+
+		$error_to_return = <<END;
+
+## WARNING ##
+
+The "to" variable is not defined properly!
+
+Either define as an array reference using brackets [] like:
+
+my \$email_recipients = ["test\@test.com"];
+
+- or - 
+
+Verify that in the object declaration, NO double quotes where used on the
+\$email_recipients variable.
+
+\$smtp_object\-\>sendEmail("TO" => \$email_recipients);
+
+END
+	
+	}
+	
+	return $error_to_return . "Error";
+
+}
+
+sub clear {
+	my $self = shift;
+	$self->server(0);
+}
+
 1;
 __END__
 
@@ -75,17 +104,17 @@ SysAdmin::SMTP - Perl Net::SMTP class wrapper module.
 
 	use SysAdmin::SMTP;
 	
-	my $smtp_object = new SysAdmin::SMTP("localhost");
+	my $smtp_object = new SysAdmin::SMTP(server => "localhost");
 	
 	my $from_address = qq("Test User" <test_user\@test.com>);
 	my $subject = "Test Subject";
 	my $message_body = "Test Message";
 	my $email_recipients = ["test_receiver\@test.com"];
 	
-	$smtp_object->sendEmail("FROM"    => "$from_address",
-                                "TO"      => "$email_recipients",
-                                "SUBJECT" => "$subject",
-                                "BODY"    => "$message_body");
+	$smtp_object->sendEmail(from    => $from_address,
+                            to      => $email_recipients,
+                            subject => $subject,
+                            body    => $message_body);
 	
 
 =head1 DESCRIPTION
@@ -99,7 +128,7 @@ SysAdmin::SMTP uses Net::SMTP, MIME::Lite to send emails.
 
 =head2 C<new()>
 
-	my $smtp_object = new SysAdmin::SMTP("localhost");
+	my $smtp_object = new SysAdmin::SMTP(server => "localhost");
 	
 Declare the SysAdmin::SMTP object instance. Takes the SMTP server as the only
 variable to use.
@@ -111,15 +140,16 @@ variable to use.
 	my $message_body = "Test Message";
 	my $email_recipients = ["test_receiver\@test.com"];
 	
-	$smtp_object->sendEmail("FROM"    => "$from_address",
-                                "TO"      => "$email_recipients",
-                                "SUBJECT" => "$subject",
-                                "BODY"    => "$message_body");
+	$smtp_object->sendEmail(from    => $from_address,
+                            to      => $email_recipients,
+                            subject => $subject,
+                            body    => $message_body);
 														
 
 =head1 SEE ALSO
 
 Net::SMTP - Simple Mail Transfer Protocol Client
+
 MIME::Lite - low-calorie MIME generator 
 
 =head1 AUTHOR
